From 114b112d53fd77ec74130c6e369bf42eac120d90 Mon Sep 17 00:00:00 2001
From: Thomas White <taw@bitwiz.org.uk>
Date: Fri, 16 Jul 2010 20:23:43 +0200
Subject: [PATCH] Configure script and makefile fixes for when DRI2 but not DRI1 is present

Previously, it was not possible to enable GLX with TLS without DRI1 enabled.

Signed-off-by: Thomas White <taw@bitwiz.org.uk>
---
 configure.ac    |   23 +++++++++++++++++++++--
 glx/Makefile.am |    5 ++++-
 2 files changed, 25 insertions(+), 3 deletions(-)

diff --git a/configure.ac b/configure.ac
index b3b752c..b800756 100644
--- a/configure.ac
+++ b/configure.ac
@@ -999,7 +999,9 @@ if test "x$RES" = xyes; then
 	REQUIRED_MODULES="$REQUIRED_MODULES $RESOURCEPROTO"
 fi
 
+AC_MSG_CHECKING([whether to use GLX])
 if test "x$GLX" = xyes; then
+	AC_MSG_RESULT([yes])
 	PKG_CHECK_MODULES([XLIB], [x11])
 	PKG_CHECK_MODULES([GL], $GLPROTO $LIBGL)
 	AC_SUBST(XLIB_CFLAGS)
@@ -1008,19 +1010,36 @@ if test "x$GLX" = xyes; then
 	GLX_SYS_LIBS="$GLX_SYS_LIBS"
 else
         GLX=no
+        AC_MSG_RESULT([no])
 fi
 AM_CONDITIONAL(GLX, test "x$GLX" = xyes)
 
-if test "x$AIGLX" = xyes -a "x$GLX" = xyes -a "x$DRI" = xyes; then
-	AC_DEFINE(AIGLX, 1, [Build AIGLX loader])
+AC_MSG_CHECKING([whether to use AIGLX])
+if test "x$AIGLX" = xyes -a "x$GLX" = xyes; then
+	if test "x$DRI" = xyes -o "x$DRI2" = xyes; then
+		AC_DEFINE(AIGLX, 1, [Build AIGLX loader])
+		AC_MSG_RESULT([yes])
+	else
+		AC_MSG_RESULT([no (neither DRI nor DRI2 enabled)])
+	fi
+
+	if test "x$DRI" = xyes; then
+		DRI_AIGLX=yes
+	fi
 else
 	AIGLX=no
+	AC_MSG_RESULT([no]);
 fi
 AM_CONDITIONAL(AIGLX, test "x$AIGLX" = xyes)
+AM_CONDITIONAL(DRI_AIGLX, test "x$DRI_AIGLX" = xyes)
 
+AC_MSG_CHECKING([whether to use GLX TLS])
 if test "x$GLX_USE_TLS" = xyes -a "x$AIGLX" = xyes; then
 	GLX_DEFINES="-DGLX_USE_TLS -DPTHREADS"
 	GLX_SYS_LIBS="$GLX_SYS_LIBS -lpthread"
+	AC_MSG_RESULT([yes])
+else
+	AC_MSG_RESULT([no])
 fi
 AC_SUBST([GLX_DEFINES])
 
diff --git a/glx/Makefile.am b/glx/Makefile.am
index 9d9fa3c..4cae6d1 100644
--- a/glx/Makefile.am
+++ b/glx/Makefile.am
@@ -50,10 +50,13 @@ glapi_sources =					\
 	glthread.h
 
 libglxdri_la_SOURCES = \
-        glxdri.c \
         extension_string.c \
         extension_string.h
 
+if DRI_AIGLX
+libglxdri_la_SOURCES += glxdri.c
+endif
+
 if DRI2_AIGLX
 libglxdri_la_SOURCES += glxdri2.c
 endif
-- 
1.7.1.1

